
### Welcome
Welcome to the user guide for Purview Automation! This is a step-by-step walkthrough of how to get started and use the library. For a shortened quick startup, see: [Quick Startup](../index.md#quick-start)


### Install purviewautomation

The first step is to install purviewautomation on your favorite code editor (Visual Studio Code, PyCharm, etc.) or add the library to a Synapse Spark Pool or a Databricks cluster.
!!! tip 
    As an optional suggestion, ensure pip is updated first by opening a terminal and running the following:
    ```
    python -m pip install --upgrade pip
    ```

To install in a code editor such as Visual Studio Code, open up a terminal and type:

```Python
pip install purviewautomation
```

### Example Install in Visual Studio Code
![Install purviewautomation](../img/tutorial/first-steps/image01.png)



Now that the library is installed, we either need to create a new Purview resource or use an existing one. Click on the bottom right of the screen to move to the next section to see how to create a Purview resource.







<!-- The simplist purviewautomation file could look like this:

```Python
{!../../../docs_src/first_steps/tutorial001.py!}
```

Copy that to a file `main.py`.

!!! note 
    The command `test this command` refers to -->